@@ -414,9 +414,10 @@ linc_protocol_get_sockaddr_unix (const LINCProtocolInfo *proto,
 		g_snprintf (buf, sizeof (buf),
 			    "%s/linc-%x-%x-%x%x",
 			    linc_tmpdir ? linc_tmpdir : "",
-			    pid, idx++,
+			    pid, idx,
 			    (guint) (rand() ^ t.tv_sec),
 			    (guint) (idx ^ t.tv_usec));
+		idx++;
 #ifdef CONNECTION_DEBUG
 		if (g_file_test (buf, G_FILE_TEST_EXISTS))
 			g_warning ("'%s' already exists !", buf);
@@ -425,9 +426,9 @@ linc_protocol_get_sockaddr_unix (const LINCProtocolInfo *proto,
 	} else 
 		actual_path = (char *)path;
 
-	pathlen = strlen (actual_path);
+	pathlen = strlen (actual_path) + 1;
 
-	if (pathlen >= sizeof (saddr->sun_path))
+	if (pathlen > sizeof (saddr->sun_path))
 		return NULL;
 
 	saddr = g_new0 (struct sockaddr_un, 1);
